@@ -24,7 +24,7 @@ class Wrapper:
             pattern used to find executables within, example: 'ws_*'
         verbosity : int, optional
             set the verbosity level, by default 0. Possible values are:
-            0 : no verbosity - all output is captured by subprocess and not printed. Both stdout and stderr can later be extracted from proc by `proc.communicate()` (which waits for the process to finish).
+            0 : no verbosity - all output is captured by subprocess and not printed. Both stdout and stderr can later be extracted from process by `process.communicate()` (which waits for the process to finish).
             1 : some verbosity - only stout is captured by subprocess and can be processed later. Errors are printed immediately (useful if you  want to know what is going on when you use Datamover directly in a jupyter notebook).
             2 : very verbose: all output is printed immediately and nothing is captured by subprocess
         """
@@ -65,8 +65,7 @@ class Wrapper:
         args = [self.path_to_exe / self.current_command] + list(args)
         stdout = subprocess.PIPE if self.verbosity < 2 else None
         stderr = subprocess.PIPE if self.verbosity < 1 else None
-        proc = subprocess.Popen(args, stdout=stdout, stderr=stderr)
-        return proc
+        return subprocess.Popen(args, stdout=stdout, stderr=stderr)
 
     def is_cluster(self):
         return len(self.exe) > 0
@@ -96,7 +95,7 @@ class Datamover(Wrapper):
             Do not change this unless you have a good reason to do so.
         verbosity : int, optional
             set the verbosity level, by default 0. Possible values are:
-            0 : no verbosity - all output is captured by subprocess and not printed. Both stdout and stderr can later be extracted from proc by `proc.communicate()` (which waits for the process to finish).
+            0 : no verbosity - all output is captured by subprocess and not printed. Both stdout and stderr can later be extracted from process by `process.communicate()` (which waits for the process to finish).
             1 : some verbosity - only stout is captured by subprocess and can be processed later. Errors are printed immediately (useful if you  want to know what is going on when you use Datamover directly in a jupyter notebook).
             2 : very verbose: all output is printed immediately and nothing is captured by subprocess
         """
@@ -148,7 +147,7 @@ class Workspace(Wrapper):
             Path to the datamover executables on the cluster, default: /usr/bin/
         verbosity : int, optional
             set the verbosity level, by default 0. Possible values are:
-            0 : no verbosity - all output is captured by subprocess and not printed. Both stdout and stderr can later be extracted from proc by `proc.communicate()` (which waits for the process to finish).
+            0 : no verbosity - all output is captured by subprocess and not printed. Both stdout and stderr can later be extracted from process by `process.communicate()` (which waits for the process to finish).
             1 : some verbosity - only stout is captured by subprocess and can be processed later. Errors are printed immediately (useful if you  want to know what is going on when you use Datamover directly in a jupyter notebook).
             2 : very verbose: all output is printed immediately and nothing is captured by subprocess
         """
@@ -201,7 +200,8 @@ class CacheWorkspace:
 
         Files will be deleted automatically one day after release.
         '''
-        self.ws.ws_release(self.id).wait()
+        process = self.ws.ws_release(self.id)
+        waitfor(process)
         self.name = None
 
     def _mk_cache(self) -> str:
@@ -212,9 +212,9 @@ class CacheWorkspace:
         str
             path to allocated workspace
         '''
-        proc = self.ws.ws_allocate(self.id, str(
+        process = self.ws.ws_allocate(self.id, str(
             self.expire_in_days), '-c', 'temporary_files')
-        out, _ = proc.communicate()
+        out, _ = process.communicate()
         self.name = out.strip().decode('utf-8')
 
     def __enter__(self) -> None:
@@ -276,14 +276,14 @@ def save_to_project(save_fn: callable, file_path: str, *args, file_path_arg_pos:
     return output
 
 
-def waitfor(proc, timeout_in_s: float = -1,
+def waitfor(process: subprocess.Popen, timeout_in_s: float = -1,
             discard_output: bool = True) -> int:
     """
     Wait for a process to complete.
 
     Parameters
     ----------
-    proc: subprocess.Popen object (e.g. returned by the Datamover class)
+    process: subprocess.Popen object (e.g. returned by the Datamover class)
     timeout_in_s: float, optional (default: endless)
         Timeout in seconds. This process will be interrupted when the timeout is reached.
     discard_output: bool, optional (default: True)
@@ -294,22 +294,22 @@ def waitfor(proc, timeout_in_s: float = -1,
     """
     start_time = time.time()
     print("Waiting .", end='', flush=True)
-    while proc.poll() is None:
+    while process.poll() is None:
         time.sleep(0.5)
         print(".", end='', flush=True)
         if timeout_in_s > 0 and (time.time() - start_time) > timeout_in_s:
             print("\n")
             warnings.warn(
-                'Timeout while waiting for process: ' + ' '.join([str(arg) for arg in proc.args]))
-            proc.kill()
-            return proc.poll()
-    exit_code = proc.poll()
+                'Timeout while waiting for process: ' + ' '.join([str(arg) for arg in process.args]))
+            process.kill()
+            return process.poll()
+    exit_code = process.poll()
     if discard_output:
-        out, err = proc.communicate()
+        out, err = process.communicate()
         warning_message = 'process: {}\nexited with error: {}\nand output: {}'.format(
-            ' '.join([str(arg) for arg in proc.args]), err, out)
+            ' '.join([str(arg) for arg in process.args]), err.strip().decode('utf-8'), out.strip().decode('utf-8'))
     else:
-        warning_message = 'process: {}\nexited with error.'.format(' '.join([str(arg) for arg in proc.args]))
+        warning_message = 'process: {}\nexited with error.'.format(' '.join([str(arg) for arg in process.args]))
     if exit_code > 0:
         warnings.warn(warning_message)
-    return proc.poll()
+    return process.poll()
